How do I convert an existing cookbook to an effortless cookbook? A new cookbook?
How do I convert and existing chef_repo to an effortless_repo? A new chef_repo?
How do I manage attributes?
What options are available in my configuration file?
How do I test using test-kitchen using CI?

## Configuration settings (`default.toml`)

### General settings

| Name                   | Type          | Default                          | Description                                                                                                               |
| ---------------------- | ------------- | -------------------------------- | ------------------------------------------------------------------------------------------------------------------------- |
| `interval`             | Integer       | `1800`                           | The number of seconds to wait between Chef Infra Client runs.                                                             |
| `splay`                | Integer       | `1800`                           | A random number of seconds between 0 and $splay to add AFTER the interval.                                                |
| `splay_first_run`      | Integer       | `0`                              | A random number of seconds between 0 and $splay_first_run BEFORE the first Chef Infra Client runs, only on the first run. |
| `run_lock_timeout`     | Integer       | `1800`                           | The number of seconds to lock the Chef Infra Client before allowing another run to begin.                                 |
| `log_level`            | String        | `"warn"`                         | The level of logging to be stored in a log file for the Chef Infra Client.                                                |
| `env_path_prefix`      | String        | `"/sbin:/usr/sbin:/usr/local/sbin:/usr/local/bin:/usr/bin:/bin"` | The level of logging to be stored in a log file for the Chef Infra Client.                |
| `ssl_verify_mode`      | String        | `":verify_peer"`                 | The verify mode for HTTPS requests.                                                                                       |

### Chef Automate settings

Chef Automate settings are part of a TOML table named `[automate]`.

Ex:

```
[automate]
enable = false
server_url = "https://<automate_url>/data-collector/v0/"
token = "<automate_token>"
```

| Name                   | Type          | Default                          | Description                                                                                                               |
| ---------------------- | ------------- | -------------------------------- | ------------------------------------------------------------------------------------------------------------------------- |
| `enable`               | Boolean       | `false`                          | Whether the Chef Infra Client should report runs to a Chef Automate server                                                |
| `server_url`           | String        | `nil`                            | The URL of the Chef Automate server to report to. Example: `https://<automate_url>/data-collector/v0/`                    |
| `token`                | String        | `nil`                            | The data_collector token with rights to the Chef Automate API.                                                            |

### Chef License settings

Chef license settings are part of a TOML table named `[chef_license]`.

Ex:

```
[automate]
enable = false
server_url = "https://<automate_url>/data-collector/v0/"
token = "<automate_token>"
```

| Name                   | Type          | Default                          | Description                                                                                                               |
| ---------------------- | ------------- | -------------------------------- | ------------------------------------------------------------------------------------------------------------------------- |
| `acceptance`           | String        | `undefined`                      | The state of . Set to "accept-no-persist" if you agree to the license.                                                |



interval = 1800
# The number of seconds to wait between Chef Infra Client runs
# Default value: 1800

splay = 1800
# A random number of seconds between 0 and $splay to add AFTER the interval. Use this setting to avoid the thundering herd problem. Optimal to always set this equal to the interval, or else you may end up DDOSing your own internal resources.
# Default value: 1800

splay_first_run = 0
# A random number of seconds between 0 and $splay_first_run BEFORE the first Chef Infra Client runs, only on the first run. Used to avoid the thundering herd problem on new deployments. Optimal to always set to a function of your node count. Add 1 second for each node in your fleet. For example, if you have 1800 nodes, then you should set this value to 1800.
# Default value: 0

run_lock_timeout = 1800
# The number of seconds to lock the Chef Infra Client before allowing another run to begin.
# Default value: 1800

log_level = "warn"
# The level of logging to be stored in a log file for the Chef Infra Client.
# Possible levels: :auto (default), :debug, :info, :warn, :error, or :fatal.
# Default value: :warn (when a terminal is available) or :info (when a terminal is not available).

env_path_prefix = "/sbin:/usr/sbin:/usr/local/sbin:/usr/local/bin:/usr/bin:/bin"
# The environment added to the path environment variable of the Chef Infra Client's run hook.
# Override this value if your Chef Infra Client needs access to a different path.
# Default value: /sbin:/usr/sbin:/usr/local/sbin:/usr/local/bin:/usr/bin:/bin

ssl_verify_mode = ":verify_peer"
# The verify mode for HTTPS requests.
# Use :verify_none for no validation of SSL certificates.
# Use :verify_peer for validation of all SSL certificates, including the Chef Infra Server connections, S3 connections, and any HTTPS remote_file resource URLs used in Chef Infra Client runs. This is the recommended setting.
# Depending on how OpenSSL is configured, the ssl_ca_path may need to be specified.
# Default value: :verify_peer.

[automate]
enable = false
server_url = "https://<automate_url>/data-collector/v0/"
token = "<automate_token>"
# The connection information for your Chef Automate server
# Setting enable = false will turn off this feature
# The server_url is the url to your Chef Automate Server
# The token is a token with the data_collector rights to the Chef Automate API
# Default value: false

#######################################
# End of optional settings
#######################################

# You must accept the Chef License to use this software: https://www.chef.io/end-user-license-agreement/. Set to "accept-no-persist" if you agree to the license.
# Change [chef_license] from acceptance = "undefined" to acceptance =

[chef_license]
acceptance = "undefined"
